@@ -72,7 +72,8 @@ void FilterEvolution::importMails(const QString &maildir)
         // Recursive import of the MBoxes.
         QDir dir(mailDir());
         const QStringList rootSubDirs = dir.entryList(QStringList(QStringLiteral("[^\\.]*")), QDir::Dirs, QDir::Name); // Removal of . and ..
-        int currentDir = 1, numSubDirs = rootSubDirs.size();
+        int currentDir = 1;
+        int numSubDirs = rootSubDirs.size();
         QStringList::ConstIterator end(rootSubDirs.constEnd());
         for (QStringList::ConstIterator filename = rootSubDirs.constBegin(); filename != end; ++filename, ++currentDir) {
             importDirContents(dir.filePath(*filename), *filename, QString());
